<?php

/*
input:
- filename: a filename (with directory information, with extension)
output: the content of the file filename as a string
*/
function fileread($filename)
{
	$handle = fopen($filename, "r");
	$str = fread($handle, filesize($filename)); 
	fclose($handle);
	
	return $str;
}


/*
input:
- filename: a filename (with directory information, with extension)
- data: a string

WRITE the content data in the file filename
*/
function filewrite($filename, $data)
{
	$handle = fopen($filename, 'w');
	fwrite($handle, $data);
	fclose($handle);
}

/*
input:
- title of the TD
- array of filenames, without extensions and without information about the directory
output: the latexcode of the TD
*/
function getTDLaTEXCode($title, $filenames)
{
	$str = fileread("latex_entete.tex") .
		"\\title{" . $title . "}" .
		"\\begin{document}" .
		"\\maketitle";
		
	foreach ($filenames as &$file) {
		if(file_exists("exercices/" . $file . ".tex"))
			$str .= "\n\n" . fileread("exercices/" . $file . ".tex");
		else
			$str .= "\n\n%file " . "exercices/" . $file . ".tex" . " not found";
	}
	
	$str .= "\n\n \\end{document}";
	
	return $str;
}




/*
input: the latexcode of an exercice typically a "\begin{exercice}.... \end{exercice}\begin{correction}...\begin{correction}" string
output: the code of a document containing the exercice and such that the result of a LaTEX compilation is a pdf or png whose size of the page crop the exercice
*/
function getTDLaTEXCodeOneExoCrop($exolatexcode)
{
	$str = fileread("latex_entete_producepng.tex") .
		"\\begin{document}";
		
	$str .= $exolatexcode;
	
	$str .= "\n\n \\end{document}";
	
	return $str;
}





/*
input: latex code of an exercice (typically a "\begin{exercice}.... \end{exercice}\begin{correction}...\begin{correction}" 
WRITE the content of a real document that crop the page to the exercice
return the name of the file (without directory information and without extension) containing this document LaTEX code
  this file is in the directory tmp
*/
function getTMPLaTEXFileCrop($exolatexcode)
{
	$mytmpfile = 'tmp/tmp.tex';
	filewrite($mytmpfile, getTDLaTEXCodeOneExoCrop($exolatexcode));
	
	return 'tmp';
}






function compile($latexfilename)
{
  chdir("tmp");
  unlink("$latexfilename.pdf");
  exec("pdflatex $latexfilename.tex");

  if(!file_exists("$latexfilename.pdf"))
	  echo fileread("$latexfilename.log");

  chdir("..");
}




/*
input: a LaTEX file (without directory information and without extension)
(but such a file exists in the directory tmp and with the extension ".tex")
output: compile the file and generate a pdf and an image .png of the pdf
*/
function compileAndGenerateImage($latexfilename)
{
        chdir("tmp");
	unlink("$latexfilename.pdf");
	exec("pdflatex $latexfilename.tex");
	exec("convert -density 100 $latexfilename.pdf  $latexfilename.png");
	exec("convert $latexfilename.png  -trim  $latexfilename.png");
	exec("convert  $latexfilename.png -transparent white $latexfilename.png");
	if(!file_exists("$latexfilename.pdf"))
	  echo fileread("$latexfilename.log");
	
	chdir("..");

}




function testCompilation($exolatexcode)
{
	$mytmpfile = getTMPLaTEXFileCrop($exolatexcode);
	compileAndGenerateImage($mytmpfile);
}


/*
input: a keywords name for an exo (without directory info and without extension)
output: the LaTEX code of the exo typically a string of the form "\begin{exercice}...\begin{exercice} \begin{correction}... \end{correction}"
*/
function exoGetLaTEXCode($exokeywords)
{
  return fileread('exercices/'. $exokeywords . ".tex");
}


/*
input: a keywords name for an exo (without directory info and without extension)
output: update the image of the exercice
*/
function updateImage($exokeywords)
{
    testCompilation(exoGetLaTEXCode($exokeywords));
    rename('tmp/tmp.png', "exercices/".$exokeywords.".png");

}



/*
- title of the TD
- array of filenames, without extensions and without information about the directory

RETURNS a source LaTEX file containing the TD
*/
function getTMPLaTEXFileTD($title, $filenames)
{
	$mytmpfile = 'tmp/mytd.tex';
	filewrite($mytmpfile, getTDLaTEXCode($title, $filenames));
	
	return $mytmpfile;
}


/*
input: 
- $pdffilename without extension and without directory information
- title of the TD
- array of filenames, without extensions and without information about the directory
PRODUCE a file "tmp/$pdffilename.pdf" containing the TD
*/
function TDcompile($pdffilename, $title, $filenames)
{
    filewrite("tmp/$pdffilename.tex", getTDLaTEXCode($title, $filenames));
    compile($pdffilename);
}

?>